TermsAndConditionsWidget class

A widget for displaying and accepting terms and conditions with a scrollable Markdown view and a button for acceptance.

The button displays a prompt to read the terms until the user has scrolled to the end. Once scrolled, the button text changes to indicate acceptance.

Inheritance

Constructors

TermsAndConditionsWidget({Key? key, String headerText = 'Terms and Conditions', String? termsContent, VoidCallback? onAccepted})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headerText String
The optional header text to be displayed above the terms. Defaults to 'Terms and Conditions'.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAccepted VoidCallback?
Callback invoked when the terms are accepted.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termsContent String?
The Markdown content for the terms and conditions. If null, default text is used.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() TermsAndConditionsWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited